@@ -1,6 +1,6 @@
 <?php
 
-if (substr($messaggio,0,4) != "var_") {
+if (substr((string) $messaggio,0,4) != "var_") {
 switch ($messaggio) {
 
 # translate YES and NO in upper case
@@ -63,8 +63,6 @@ case "Mostrare la caparra se presente?":          	$messaggio = "Zeige Vorauszah
 case "Mostrare quali sono i giorni pieni all'interno dei periodi dove non c'è più disponibilità?":        	$messaggio = "Zeige welche Tage voll der Periode entsprechen, in der nichts verfügbar ist?"; break;
 case "Mostrare la form di richiesta prenotazione?":        	$messaggio = "Das Formular zur Reservierungsanforderung zeigen?"; break;
 case "Indirizzo email a cui inviare le richieste di prenotazione":      $messaggio = "Email Addresse f&uuml;r Registrierungsanfragen"; break;
-case "Mascherare la provenienza dell'email sull'envelope?":        	$messaggio = "Verstecke den Absender auf dem Emailkopf?"; break;
-case "provare a cambiare se non si riescono a spedire le email":        $messaggio = "&auml;ndern Sie das falls sie keine Email senden k&ouml;nnen."; break;
 case "Tag html di apertura per la formattazione delle font":        	$messaggio = "&Ouml;ffnendes HTML-Tag zur Schriftformatierung"; break;
 case "Tag html di chiusura per la formattazione delle font":        	$messaggio = "Schlie&szlig;endes HTML-Tag zur Schriftformatierung"; break;
 case "Tag html di apertura per la formattazione delle font rosse":     	$messaggio = "&Ouml;ffnendes HTML-Tag zur Formatierung roter Schriftarten"; break;
@@ -242,7 +240,6 @@ case "eventuali pagine già presenti nella cartella":	$messaggio = "Seiten die s
 case "verranno <b style=\"font-weight: normal; color: red;\">sovrascritte</b>":	$messaggio = "werden <b style=\"font-weight: normal; color: red;\">&uuml;berschrieben</b>"; break;
 case "Pagine importate":  			        $messaggio = "Seiten importiert"; break;
 case "con i servizi opzionali selezionati":          	$messaggio = "mit ausgew&auml;hlten optionalen Diensten"; break;
-case "Utilizzare le liste di nazioni, regioni, etc. dell'utente":  $messaggio = "Benutze Listen mit Nationen, Regionen usw. von Benutzer"; break;
 case "Url del file css per la modalità frame":        	$messaggio = "Url einer CSS-Datei f&uuml;r Darstellung mit Frames"; break;
 case "Utilizza per l'aspetto della pagina":  	        $messaggio = "Benutze f&uuml;r Seitendarstellung"; break;
 case "html personalizzato":                          	$messaggio = "Allgemeines HTML"; break;
@@ -265,11 +262,17 @@ case "URL del logo":  				$messaggio = "URL f&uuml;r Logo"; break;
 case "Valore del tema":  			$messaggio = "Wert f&uuml;r Thema"; break;
 case "Esempio di codice html per includere il primo passo della form in modalità frame su altre pagine del sito":	$messaggio = "Example of html code to include the first step of the form in framed mode on other website pages"; break;
 case "selezionare \"html personalizzato\" nell'aspetto della pagina per modificarla":	$messaggio = "W&auml;hle \"Allgemeines HTML\" in \"Seitendarstellung\" um es zu &auml;ndern"; break;
+case "chiedere":  				$messaggio = "ask"; break;
+case "il":  					$messaggio = "the"; break;
+case "Crea Pagine Web":  			$messaggio = "Create Web Pages"; break;
 case "Postgresql":  				$messaggio = "Postgresql"; break;
 case "Mysql":  					$messaggio = "Mysql"; break;
 case "Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto":	$messaggio = "Motivations of assignment rules 1 for conditional availability to consider"; break;
+case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
 case "Nome":  					$messaggio = "Name"; break;
 case "Email":  					$messaggio = "Email"; break;
+case "Email alternativa":  			$messaggio = "Alternative email"; break;
+case "Email certificata (PEC) o codice destinatario":	$messaggio = "Certified email"; break;
 case "Aprile":  				$messaggio = "April"; break;
 case "Agosto":  				$messaggio = "August"; break;
 case "Settembre":  				$messaggio = "September"; break;
@@ -284,13 +287,56 @@ case "Numero di settimane dopo cui prendere richieste errato":	$messaggio = "Wro
 case "Numero di giorni dopo cui prendere richieste errato":	$messaggio = "Wrong number of days after which take requests"; $tr = 1; break;
 case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Align availability with arrival date?"; break;
 case "Importa":  				$messaggio = "Import"; break;
-case "nomi dall'utente delle liste, opzionali nel commento":	$messaggio = "names from lists user, optionals in comment"; break;
+case "Utilizzare le personalizzazioni (tipi di persone, liste di nazioni, regioni, ecc.) dell'utente":	$messaggio = "Use customizations (people types, lists of nations, regions, etc.) from user"; break;
+case "Url del file javascript per la modalità frame":	$messaggio = "Url of javascript file for framed mode"; break;
+case "nomi dall'utente delle personalizzazioni":	$messaggio = "names from customizations user"; break;
 case "Categoria":  				$messaggio = "Category"; break;
 case "Attenzione":  				$messaggio = "Warning"; break;
 case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "rules 1 for closure are always applied"; break;
 case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "The requested type is closed in this period"; break;
-case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
 case "Spostamento orizzontale della posizione":	$messaggio = "Horizontal offset for position"; break;
+case "aggiunto al commento":  			$messaggio = "added to comment"; break;
+case "aggiunto al campo":  			$messaggio = "added to field"; break;
+case "del cliente":  				$messaggio = "in client data"; break;
+case "URL file css":  				$messaggio = "URL of css file"; break;
+case "URL file javascript":  			$messaggio = "URL of javascript file"; break;
+case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "there are rates without assignment rule n. 2"; break;
+case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
+case "Partita iva":  				$messaggio = "VAT number"; break;
+case "mai":  					$messaggio = "never"; break;
+case "se possibile":  				$messaggio = "when possible"; break;
+case "sempre":  				$messaggio = "always"; break;
+case "posizioni vicine":  			$messaggio = "nearby positions"; break;
+case "con posizioni vicine":  			$messaggio = "with nearby positions"; break;
+case "Indirizzi alternativi da cui la pagina è raggiungibile":	$messaggio = "Alternative addresses from which the page can be reached"; break;
+case "sicuro":  				$messaggio = "secure"; break;
+case "usare uno spazio per non mostrare il costo nei dettagli":	$messaggio = "use a space to don't show the cost in the details"; break;
+case "Codici promozionali":  			$messaggio = "Promotional codes"; break;
+case "Il codice":  				$messaggio = "The code"; break;
+case "aggiunge":  				$messaggio = "adds"; break;
+case "rimuove":  				$messaggio = "removes"; break;
+case "Codice promozionale":  			$messaggio = "Promotional code"; break;
+case "Solo quelli selezionati per essere mostrati":	$messaggio = "only the ones selected to be shown"; break;
+case "Codice promozionale applicato":  		$messaggio = "Promotional code applied"; break;
+case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "some extra costs with promotional code"; break;
+case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili":	$messaggio = "are not associated to any rate, some of their characteristics may be altered if not compatible"; break;
+case "Mostrare le date passate?":  		$messaggio = "Show past dates?"; break;
+case "titolo html":  				$messaggio = "html title"; break;
+case "titolo":  				$messaggio = "title"; break;
+case "Si deve inserire almeno una persona che possa essere legalmente responsabile":	$messaggio = "You must include at least one person who can be legally responsible"; break;
+case "Solo quando non c'è disponibilità":  	$messaggio = "Only when there is no availability"; break;
+case "Sempre":  				$messaggio = "Always"; break;
+case "Raggruppamento":  			$messaggio = "Grouping"; break;
+case "Valuta della caparra":  			$messaggio = "Deposit currency"; break;
+case "Seconda email":  				$messaggio = "Second email"; break;
+case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
+case "non deve contenere \"php\" e deve terminare con \".js\"":	$messaggio = "must not contain \"php\" and must end with \".js\""; break;
+case "notte":  					$messaggio = "night"; break;
+case "notti":  					$messaggio = "nights"; break;
+case "cambia date":  				$messaggio = "change dates"; break;
+case "Per questa tariffa si deve inserire un minimo di":	$messaggio = "For this rate you have to insert at least"; break;
+case "Secondo cognome":  			$messaggio = "Second surname"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -298,15 +344,15 @@ case "":  		$messaggio = ""; break;
 case "mdl_disponibilita":                          	$messaggio = "verfuegbarkeitscheck"; break;
 
 } # fine switch ($messaggio)
-} # fine if (substr($messaggio,0,4) != "var_")
+} # fine if (substr((string) $messaggio,0,4) != "var_")
 
 
 else {
 switch ($messaggio) {
 
-# NAMES OF VARIABLES: for translation leave the beginning as var_ and use only a-z, A-Z, 
-# 0-9 and _ (underscore). No spaces, no accents! There must not be 2 with the same name.
-# NOTE: names of variables are only shown when editing files, actually they don't need to be translated
+# NAMES OF VARIABLES: for translation leave the beginning as var_ and use only ASCII a-z, A-Z, 0-9 
+# and _ (underscore). No spaces, no accents! No special characters! There must not be 2 with the same name.
+# NOTE: names of variables are only shown when editing files, actually *they don't need to be translated*
 case "var_nome_pagina":                          	$messaggio = "var_Seiten_Name"; break;
 case "var_anno":                                  	$messaggio = "var_Jahr"; break;
 case "var_tipo_db":                                  	$messaggio = "var_db_Typ"; break;
@@ -330,7 +376,6 @@ case "var_mostra_frase_alternativa_regola1":          	$messaggio = "var_zeige_A
 case "var_mostra_caparra":                          	$messaggio = "var_zeige_Anzahlung"; break;
 case "var_mostra_richiesta_via_mail":                  	$messaggio = "var_zeige_Emailanfrage"; break;
 case "var_indirizzo_email":                          	$messaggio = "var_Email_Adresse"; break;
-case "var_maschera_email":                          	$messaggio = "var_verstecke_Email_Kopf"; break;
 case "var_mostra_giorni_pieni":                  	$messaggio = "var_zeige_alle_Tage"; break;
 case "var_apertura_tag_font":                          	$messaggio = "var_font_tag_Anfang"; break;
 case "var_chiusura_tag_font":                          	$messaggio = "var_font_tag_schliessen"; break;
@@ -404,6 +449,8 @@ case "var_utente_liste":  			$messaggio = "var_lists_user"; break;
 case "var_estendi_ultima_data":  		$messaggio = "var_extend_last_date"; break;
 case "var_costi_aggiuntivi_mostra":  		$messaggio = "var_extra_costs_to_show"; break;
 case "var_categorie_costi_agg_imposte":  	$messaggio = "var_imposed_extra_costs_categories"; break;
+case "var_campi_codici_promo":  		$messaggio = "var_fields_promo_codes"; break;
+case "var_costi_campi_codici_promo":  		$messaggio = "var_costs_fields_promo_codes"; break;
 case "var_mostra_bottone_paypal":  		$messaggio = "var_show_paypal_button"; break;
 case "var_nome_modello_paypal":  		$messaggio = "var_paypal_template_name"; break;
 case "var_origine_prenotazione":  		$messaggio = "var_reservation_origin"; break;
@@ -416,10 +463,12 @@ case "var_stile_riquadro_calendario":  		$messaggio = "var_calendar_box_style";
 case "var_stile_tabella_calendario":  		$messaggio = "var_calendar_table_style"; break;
 case "var_stile_bottoni_calendario":  		$messaggio = "var_calendar_buttons_style"; break;
 case "var_stile_bottone_apertura_calendario":  	$messaggio = "var_open_calendar_button_style"; break;
+case "var_spostamento_orizzontale_calendario":  $messaggio = "var_calendar_horizontal_offset"; break;
 case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_active_calendar_date"; break;
 case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_selected_calendar_date"; break;
 case "var_stile_tabella_prenotazione":  	$messaggio = "var_reservation_table_style"; break;
 case "var_file_css_frame":  			$messaggio = "var_framed_css_file"; break;
+case "var_file_js_frame":  			$messaggio = "var_framed_js_file"; break;
 case "var_apri_nuova_finestra_da_frame":  	$messaggio = "var_open_new_window_from_frame"; break;
 case "var_larghezza_finestra_da_frame":  	$messaggio = "var_window_from_frame_width"; break;
 case "var_altezza_finestra_da_frame":  		$messaggio = "var_window_from_frame_height"; break;
@@ -427,15 +476,22 @@ case "var_tema_modello":  			$messaggio = "var_template_theme"; break;
 case "var_colore_tema":  			$messaggio = "var_theme_color"; break;
 case "var_valore_tema":  			$messaggio = "var_theme_value"; break;
 case "var_allinea_disponibilita_con_arrivo":	$messaggio = "var_align_availability_with_arrival"; break;
+case "var_mostra_date_passate":  		$messaggio = "var_show_past_dates"; break;
 case "var_fr_E_necessario_inserire_il_numero_di_persone_ecc":	$messaggio = "var_fr_The_number_of_people_is_needed_etc"; break;
 case "var_fr_Nome":  				$messaggio = "var_phr_Name"; break;
 case "var_fr_Email":  				$messaggio = "var_phr_Email"; break;
+case "var_fr_Email_alternativa":  		$messaggio = "var_phr_Alternative_email"; break;
+case "var_fr_Email_certificata_o_codice_destinatario":	$messaggio = "var_phr_Certified_email"; break;
 case "var_fr_Richiesta_di_prenotazione_inviata":	$messaggio = "var_phr_Request_for_reservation_sent"; break;
 case "var_fr_da":  				$messaggio = "var_phr_from2"; break;
 case "var_fre_Email":  				$messaggio = "var_phre_Email"; break;
+case "var_fre_Email_alternativa":  		$messaggio = "var_phre_Alternative_email"; break;
+case "var_fre_Email_certificata_o_codice_destinatario":	$messaggio = "var_phre_Certified_email"; break;
 case "var_fre_Nome":  				$messaggio = "var_phre_Name"; break;
+case "var_fre_Valuta_della_caparra":  		$messaggio = "var_phre_Deposit_currency"; break;
 case "var_fr_Richesta_prenotazione":  		$messaggio = "var_phr_Reservation_request"; break;
 case "var_fr_appartamento":  			$messaggio = "var_phr_apartment"; break;
+case "var_cerca_appartamenti_vicini":  		$messaggio = "var_search_nearby_apartments"; break;
 case "var_fr_in":  				$messaggio = "var_phr_in"; break;
 case "var_fre_Persone":  			$messaggio = "var_phre_People"; break;
 case "var_fr_Scegliere_le_settimane_in_cui_applicare":	$messaggio = "var_phr_Choose_the_weeks_to_be_applied_for"; break;
@@ -476,6 +532,8 @@ case "var_utente_messaggio":  			$messaggio = "var_message_user"; break;
 case "var_chiedi_cognome":  			$messaggio = "var_ask_surname"; break;
 case "var_chiedi_nome":  			$messaggio = "var_ask_name"; break;
 case "var_chiedi_email":  			$messaggio = "var_ask_email"; break;
+case "var_chiedi_email2":  			$messaggio = "var_ask_email2"; break;
+case "var_chiedi_email_cert":  			$messaggio = "var_ask_cert_email"; break;
 case "var_chiedi_sesso":  			$messaggio = "var_ask_sex"; break;
 case "var_chiedi_datanascita":  		$messaggio = "var_ask_birthdate"; break;
 case "var_chiedi_documento":  			$messaggio = "var_ask_document"; break;
@@ -489,13 +547,17 @@ case "var_chiedi_telefono":  			$messaggio = "var_ask_telephone"; break;
 case "var_chiedi_telefono2":  			$messaggio = "var_ask_telephone2"; break;
 case "var_chiedi_telefono3":  			$messaggio = "var_ask_telephone3"; break;
 case "var_chiedi_fax":  			$messaggio = "var_ask_fax"; break;
+case "var_chiedi_codfiscale":  			$messaggio = "var_ask_fiscalcode"; break;
+case "var_chiedi_partitaiva":  			$messaggio = "var_ask_vatnumber"; break;
 case "var_chiedi_commento":  			$messaggio = "var_ask_comment"; break;
 case "var_chiedi_oracheckin":  			$messaggio = "var_ask_checkintime"; break;
+case "var_chiedi_valutapagamento":  		$messaggio = "var_ask_paymentcurrency"; break;
 case "var_chiedi_metodopagamento":  		$messaggio = "var_ask_paymentmethod"; break;
 case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_payment_methods_to_ask"; break;
 case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_imposed_payment_methods_names"; break;
 case "var_campi_form_personalizzati":  		$messaggio = "var_custom_form_fields"; break;
 case "var_chiedi_campi_form_personalizzati":  	$messaggio = "var_ask_custom_form_fields"; break;
+case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_custom_form_fields"; break;
 case "var_campi_form_doc_condizioni":  		$messaggio = "var_doc_conditions_form_fields"; break;
 case "var_chiedi_campi_form_doc_condizioni":  	$messaggio = "var_ask_doc_conditions_form_fields"; break;
 case "var_fr_Cognome":  			$messaggio = "var_phr_Surname"; break;
@@ -512,7 +574,10 @@ case "var_fr_Telefono":  			$messaggio = "var_phr_Telephone"; break;
 case "var_fr_Secondo_telefono":  		$messaggio = "var_phr_Second_telephone"; break;
 case "var_fr_Terzo_telefono":  			$messaggio = "var_phr_Third_telephone"; break;
 case "var_fr_Fax":  				$messaggio = "var_phr_Fax"; break;
+case "var_fr_Codice_fiscale":  			$messaggio = "var_phr_Fiscal_code"; break;
+case "var_fr_Partita_iva":  			$messaggio = "var_phr_VAT_number"; break;
 case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_phr_Estimated_arrival_time"; break;
+case "var_fr_Valuta_della_caparra":		$messaggio = "var_phr_Deposit_currency"; break;
 case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phr_Deposit_payment_method"; break;
 case "var_fre_Cognome":  			$messaggio = "var_phre_Surname"; break;
 case "var_fre_Genere":  			$messaggio = "var_phre_Gender"; break;
@@ -528,6 +593,8 @@ case "var_fre_Telefono":  			$messaggio = "var_phre_Telephone"; break;
 case "var_fre_Secondo_telefono":  		$messaggio = "var_phre_Second_telephone"; break;
 case "var_fre_Terzo_telefono":  		$messaggio = "var_phre_Third_telephone"; break;
 case "var_fre_Fax":  				$messaggio = "var_phre_Fax"; break;
+case "var_fre_Codice_fiscale":  		$messaggio = "var_phre_Fiscal_code"; break;
+case "var_fre_Partita_iva":  			$messaggio = "var_phre_VAT_number"; break;
 case "var_fre_Orario_stimato_di_arrivo":  	$messaggio = "var_phre_Estimated_arrival_time"; break;
 case "var_fre_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phre_Deposit_payment_method"; break;
 case "var_fr_campi_necessari":  		$messaggio = "var_phr_required_fields"; break;
@@ -548,12 +615,22 @@ case "var_fr_Data_di_partenza":  		$messaggio = "var_phr_Departure_date"; break;
 case "var_fr_Tipologia":  			$messaggio = "var_phr_Type"; break;
 case "var_fr_Accetto":  			$messaggio = "var_phr_I_accept"; break;
 case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_phr_The_requested_type_is_closed_in_this_period"; break;
+case "var_fr_posizioni_vicine":  		$messaggio = "var_phr_nearby_positions"; break;
+case "var_fr_con_posizioni_vicine":  		$messaggio = "var_phr_with_nearby_positions"; break;
+case "var_fr_Codice_promozionale":  		$messaggio = "var_phr_Promotional_code"; break;
+case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_phr_Promotional_code_applied"; break;
+case "var_fr_Si_deve_inserire_almeno_una_persona_che_possa_ecc":	$messaggio = "var_phr_You_must_include_at_least_one_person_who_can_etc"; break;
+case "var_fr_notte":  				$messaggio = "var_phr_night"; break;
+case "var_fr_notti":  				$messaggio = "var_phr_nights"; break;
+case "var_fr_cambia_date":  			$messaggio = "var_phr_change_dates"; break;
+case "var_fr_Per_questa_tariffa_si_deve_inserire_un_minimo_di":	$messaggio = "var_phr_For_this_rate_you_have_to_insert_at_least"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
-case "var_spostamento_orizzontale_calendario":  $messaggio = "var_calendar_horizontal_offset"; break;
+case "var_chiedi_cognome2":  			$messaggio = "var_ask_surname2"; break;
+case "var_fr_Secondo_cognome":  		$messaggio = "var_phr_Second_surname"; break;
 } # fine switch ($messaggio)
-} # fine else if (substr($messaggio,0,4) != "var_")
+} # fine else if (substr((string) $messaggio,0,4) != "var_")
 
 
 
-?>
\ No newline at end of file
+?>
