@@ -30,7 +30,6 @@ case "della tariffa arrotondato a":                                      $messag
 case "considera il costo percentuale come letto(i) aggiuntivo(i)":       $messaggio = "verwende diese prozentualen Zuschl&auml;ge wie Zusatzbett(en)"; break;
 case "Procedi nell'inserimento del nuovo costo aggiuntivo":              $messaggio = "Einf&uuml;gen des neuen Zuschlages"; break;
 case "Caparra":                                                          $messaggio = "Anzahlung"; break;
-case "La caparra normale per la":                                        $messaggio = "Die &uuml;bliche Anzahlung f&uuml;r"; break;
 case "arrotondata a":                                                    $messaggio = "gerundet zu"; break;
 case "Inserisci o modifica la caparra":                                  $messaggio = "Eingeben oder &auml;ndern der Anzahlung"; break;
 case "Vedi i prezzi già inseriti":                                       $messaggio = "Bisher eingegebene Preise anzeigen"; break;
@@ -220,7 +219,6 @@ case "La caparra è errata":                                             $messag
 case "è":                                                               $messaggio = "ist"; break;
 case "il":                                                               $messaggio = "auf"; break;
 case "Commissioni":                                                      $messaggio = "Nachl&auml;sse"; break;
-case "Le commissioni normali sulla":                                     $messaggio = "Der Nachlass f&uuml;r"; break;
 case "sono":                                                             $messaggio = "wird"; break;
 case "Inserisci o modifica le commissioni":                              $messaggio = "speichern der Nachl&auml;sse"; break;
 case "Tasse":                                                            $messaggio = "Steuern"; break;
@@ -252,12 +250,14 @@ case "prezzo per persona per giorno":  		$messaggio = "Preis pro Person und Tag"
 case "p":  					$messaggio = "p"; break;
 case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Schnelles Einf&uuml;gen eines neuen Zuschlags f&uuml;r"; break;
 case "permanenza minima":  			$messaggio = "Mindestaufenthalt"; break;
-case "numero di bambini":  			$messaggio = "Anzahl Kinder"; break;
 case "letto aggiuntivo":  			$messaggio = "Zusatzbett"; break;
 case "offerta speciale":  			$messaggio = "Benutzerdefiniert"; break;
 case "inserisci":  				$messaggio = "Einf&uuml;gen"; break;
 case "Se":  					$messaggio = "If"; break;
 case "Se si inseriscono":  			$messaggio = "If"; break;
+case "a":  					$messaggio = "to"; break;
+case "Crea Prezzi":  				$messaggio = "Insert Prices"; break;
+case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
 case "Nessun dato è stato inserito":  		$messaggio = "No data has been inserted"; break;
 case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>single</b> extra cost"; break;
 case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>weekly</b> extra cost"; break;
@@ -268,7 +268,11 @@ case "se anche un solo giorno della prenotazione è all'interno dei periodi sele
 case "Costo aggiuntivo già esistente":  	$messaggio = "Extra cost already inserted"; break;
 case "i prezzi della":  			$messaggio = "the prices to"; break;
 case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Display grouped with similar costs from same category in insertion"; break;
+case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
 case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
+case "della tar.":  				$messaggio = "of rate"; break;
+case "di t.+s.":  				$messaggio = "of r.+d."; break;
+case "di t.+s.+c.a.":  				$messaggio = "of r.+d.+e.c."; break;
 case "parte fissa della tariffa":  		$messaggio = "fixed part of the rate"; break;
 case "parte per una persona della tariffa":  	$messaggio = "one person part of the rate"; break;
 case "Numero massimo":  			$messaggio = "Maximum number"; break;
@@ -279,14 +283,15 @@ case "Combina con altri costi":			$messaggio = "Combine with other costs"; break
 case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "combined costs are shown all together with category name and each one is inserted when possible"; break;
 case "opzionale":  				$messaggio = "optional"; break;
 case "Costi combinati":  			$messaggio = "Combined costs"; break;
+case "numero di neonati":  			$messaggio = "number of infants"; break;
 case "Inserisci il costo aggiuntivo":  		$messaggio = "Insert the extra cost"; break;
 case "Numero minimo di giorni":  		$messaggio = "Minimum number of days"; break;
 case "Applicato alle tariffe":  		$messaggio = "Applied to rates"; break;
 case "Periodi in cui viene applicato il costo":	$messaggio = "Periods in which the cost is applied"; break;
-case "Valore dello sconto per ogni bambino":  	$messaggio = "Discount value for each child"; break;
+case "Valore per ogni neonato":  		$messaggio = "Value for each infant"; break;
 case "del prezzo di una persona":  		$messaggio = "of the price for one person"; break;
 case "solo per tariffe con prezzi a persona":  	$messaggio = "only for rates with per person prices"; break;
-case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "with this cost the number of children must be included in the number of people too"; break;
+case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "with this cost the number of infants is not included in the number of people"; break;
 case "Valore del letto aggiuntivo":  		$messaggio = "Value of the extra bed"; break;
 case "Valore dello sconto":  			$messaggio = "Discount value"; break;
 case "del prezzo totale":  			$messaggio = "of total price"; break;
@@ -304,6 +309,28 @@ case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo per
 case "tutte le tariffe":  			$messaggio = "all rates"; break;
 case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
 case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
+case "in tutti i periodi in modo predefinito":	$messaggio = "in all periods by default"; break;
+case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "imports its prices from other rates, so can't export its prices"; break;
+case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "already imports its prices from other rates in these periods, can't import other prices"; break;
+case "modifica":  				$messaggio = "modify"; break;
+case "In modo predefinito importa":  		$messaggio = "By default import"; break;
+case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
+case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
+case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
+case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
+case "Se si moltiplica per il numero di persone":	$messaggio = "When multiplying by the number of people"; break;
+case "escludi":  				$messaggio = "exclude"; break;
+case "includi solo":  				$messaggio = "include only"; break;
+case "questi tipi":  				$messaggio = "these types"; break;
+case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
+case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
+case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
+case "tariffe con":  				$messaggio = "rates with"; break;
+case "per persona nullo":  			$messaggio = "per person zero"; break;
+case "fisso nullo":  				$messaggio = "fixed zero"; break;
+case "da per persona":  			$messaggio = "from per person"; break;
+case "più fisso":  				$messaggio = "from fixed"; break;
+case "dal fisso":  				$messaggio = "plus fixed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
