@@ -15,6 +15,7 @@ case "Inserisci una nuova password":  		$messaggio = "Neues Passwort eingeben";
 case "Ripeti la password":  			$messaggio = "Passwort wiederholen"; break;
 case "Continua":  				$messaggio = "Weiter"; break;
 case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
+case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Already exists</div> an user called"; break;
 case "Nuova password dell'utente":  		$messaggio = "Neues Passwort f&uuml;r Benutzer"; break;
 case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "Es wurde <b>nichts</b> ge&auml;ndert"; break;
 case "Esiste già un utente chiamato":  		$messaggio = "Es existiert bereits ein Benutzer mit Namen"; break;
@@ -35,7 +36,6 @@ case "Abilitare per usare altri utenti":  	$messaggio = "Aktivieren zur Benutzun
 case "Modifica gli utenti":  			$messaggio = "Benutzer &auml;ndern"; break;
 case "Aggiungi":  				$messaggio = "Hinzuf&uuml;gen"; break;
 case "un nuovo utente chiamato":  		$messaggio = "ein neuer Benutzer mit Namen"; break;
-case "Importa i privilegi":  			$messaggio = "Berechtigungen importieren"; break;
 case "dell'utente":  				$messaggio = "f&uuml;r Benutzer"; break;
 case "del gruppo":  				$messaggio = "von Gruppe"; break;
 case "dall'utente":  				$messaggio = "von Benutzer"; break;
@@ -50,13 +50,27 @@ case "cancella":  				$messaggio = "L&ouml;schen"; break;
 case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Sind Sie sicher, dass Sie den folgende Benutzer <b style=\"font-weight: normal; color: red;\">l&ouml;schen</b> wollen?"; break;
 case "SI":  					$messaggio = "JA"; break;
 case "NO":  					$messaggio = "NEIN"; break;
-case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Already exists</div> an user called"; break;
+case "Gestione Utenti":  			$messaggio = "Users Management"; break;
 case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">not</div> inserted correctly"; break;
+case "Gestione degli utenti":			$messaggio = "Users management"; break;
 case "Amministratore":  			$messaggio = "Administrator"; break;
 case "Importa":  				$messaggio = "Import"; break;
+case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizations"; break;
+case "solo i privilegi":  			$messaggio = "only privileges"; break;
+case "solo le personalizzazioni":  		$messaggio = "only customizations"; break;
+case "Personalizzazioni importate":  		$messaggio = "Customizations imported"; break;
+case "privilegi, personalizzazioni e gruppi":	$messaggio = "privileges, customizations and groups"; break;
+case "privilegi e gruppi":  			$messaggio = "privileges and groups"; break;
+case "personalizzazioni e gruppi":  		$messaggio = "customizations and groups"; break;
+case "solo i gruppi":  				$messaggio = "only groups"; break;
+case "Gruppi importati":  			$messaggio = "Groups imported"; break;
+case "Password aggiornata":  			$messaggio = "Password updated"; break;
+case "Password troppo debole":			$messaggio = "Password too weak"; break;
+case "almeno":  				$messaggio = "at least"; break;
+case "caratteri":  				$messaggio = "characters"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
