@@ -61,25 +61,6 @@ case " e vi erano":                                              $messaggio = "
 case "prenotazioni che finivano dopo il limite posto al ":       $messaggio = "Reservierungen die Enden nach dem Limit das gesetzt wurde f&uuml;r "; break;
 case ", queste prenotazioni non sono state importate":           $messaggio = ", diese Reservierungen wurden nicht importiert"; break;
 case "Anno già creato":                                         $messaggio = "Jahr wurde bereits erstellt"; break;
-case " Do":                                                      $messaggio = " So"; break;
-case " Lu":                                                      $messaggio = " Mo"; break;
-case " Ma":                                                      $messaggio = " Di"; break;
-case " Me":                                                      $messaggio = " Mi"; break;
-case " Gi":                                                      $messaggio = " Do"; break;
-case " Ve":                                                      $messaggio = " Fr"; break;
-case " Sa":                                                      $messaggio = " Sa"; break;
-case "Gen":                                                      $messaggio = "Jan"; break;
-case "Feb":                                                      $messaggio = "Feb"; break;
-case "Mar":                                                      $messaggio = "M&auml;r"; break;
-case "Apr":                                                      $messaggio = "Apr"; break;
-case "Mag":                                                      $messaggio = "Mai"; break;
-case "Giu":                                                      $messaggio = "Jun"; break;
-case "Lug":                                                      $messaggio = "Jul"; break;
-case "Ago":                                                      $messaggio = "Aug"; break;
-case "Set":                                                      $messaggio = "Sep"; break;
-case "Ott":                                                      $messaggio = "Okt"; break;
-case "Nov":                                                      $messaggio = "Nov"; break;
-case "Dic":                                                      $messaggio = "Dez"; break;
 case "Il formato dell'anno richiesto è sbagliato":              $messaggio = "Das Format des gew&uuml;nschten Jahres ist falsch"; break;
 case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":        $messaggio = "Monate wurden falsch ausgew&auml;hlt, sie wurden von J&auml;nner bis Dezember eingetragen."; break;
 case "Cognome del cliente":                                      $messaggio = "Nachname des Kunden"; break;
@@ -121,6 +102,18 @@ case "Benvenuto a HOTELDRUID":  		$messaggio = "Welcome to HOTELDRUID"; break;
 case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
 case "crea il database":  			$messaggio = "create database"; break;
 case "Promemoria":  				$messaggio = "Reminder"; break;
+case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
+case "Avviso":  				$messaggio = "Warning"; break;
+case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
+case "mesi":  					$messaggio = "months"; break;
+case "OK, ho capito":  				$messaggio = "OK, got it"; break;
+case "Crea Anno":  				$messaggio = "Create Year"; break;
+case "Nota":  					$messaggio = "Notice"; break;
+case "l'anno":  				$messaggio = "year"; break;
+case "verrà archiviato automaticamente il":  	$messaggio = "will be automatically archived on"; break;
+case "nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "meanwhile you can add periods beyond"; break;
+case "ricordarsi di tornare al":  		$messaggio = "remember to come back to"; break;
+case "una volta conclusa la consultazione del":	$messaggio = "once finished consulting the"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
