@@ -42,14 +42,19 @@ case "Modifica gli ospiti delle prenotazioni":           $messaggio = "G&auml;st
 case "della prenotazione":                               $messaggio = "der Reservierung"; break;
 case "Gli ospiti delle prenotazioni":                    $messaggio = "Die G&auml;ste der Reservierung"; break;
 case "ln.":  					         $messaggio = "ln."; break;
+case "Modifica Ospiti":  			$messaggio = "Modify Guests"; break;
 case "nato il":  				$messaggio = "born the"; break;
 case "nata il":  				$messaggio = "born the"; break;
 case "scadenza":  				$messaggio = "expiration"; break;
 case "nazione":  				$messaggio = "nation"; break;
 case "Nazione":  				$messaggio = "Nation"; break;
+case "email":  					$messaggio = "email"; break;
+case "2ª email":  				$messaggio = "2nd email"; break;
+case "PEC/codice":  				$messaggio = "certified email"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
