@@ -6,7 +6,6 @@ case "Configura e personalizza HotelDruid":	$messaggio = "Hoteldruid konfigurier
 case "Scegli la lingua":  			$messaggio = "Sprache w&auml;hlen"; break;
 case "cambia la lingua":  			$messaggio = "Sprache &auml;ndern"; break;
 case "Tabella con tutte le prenotazioni":  	$messaggio = "Tabelle mit allen Reservierungen"; break;
-case "Cambia la valuta":  			$messaggio = "W&auml;hrung &auml;ndern"; break;
 case "Scegli le colonne da far comparire":  	$messaggio = "W&auml;hlen Sie die Spalten die angezeigt werden sollen"; break;
 case "n° di settimane":  			$messaggio = "Wochenanzahl"; break;
 case "n° di giorni":  				$messaggio = "Tagesanzahl"; break;
@@ -72,25 +71,6 @@ case "spazio":  				$messaggio = "Leerzeichen"; break;
 case "trattino":  				$messaggio = "Bindestrich"; break;
 case "a capo":  				$messaggio = "neue Zeile"; break;
 case "Pagine per il sito web":  		$messaggio = "Webseiten"; break;
-case " Do":  					$messaggio = " So"; break;
-case " Lu":  					$messaggio = " Mo"; break;
-case " Ma":  					$messaggio = " Di"; break;
-case " Me":  					$messaggio = " Mi"; break;
-case " Gi":  					$messaggio = " Do"; break;
-case " Ve":  					$messaggio = " Fr"; break;
-case " Sa":  					$messaggio = " Sa"; break;
-case "Gen":  					$messaggio = "Jan"; break;
-case "Feb":  					$messaggio = "Feb"; break;
-case "Mar":  					$messaggio = "M&auml;r"; break;
-case "Apr":  					$messaggio = "Apr"; break;
-case "Mag":  					$messaggio = "Mai"; break;
-case "Giu":  					$messaggio = "Jun"; break;
-case "Lug":  					$messaggio = "Jul"; break;
-case "Ago":  					$messaggio = "Aug"; break;
-case "Set":  					$messaggio = "Sep"; break;
-case "Ott":  					$messaggio = "Okt"; break;
-case "Nov":  					$messaggio = "Nov"; break;
-case "Dic":  					$messaggio = "Dez"; break;
 case "nome della tariffa":  			$messaggio = "Bezeichnung des Tarifs"; break;
 case "data di inserimento":  			$messaggio = "Eintragsdatum"; break;
 case "tariffa completa":  			$messaggio = "Gesamtpreis"; break;
@@ -159,7 +139,6 @@ case "Il mascheramento della provenienza delle email è stato cambiato":	$messag
 case "SI":  					$messaggio = "JA"; break;
 case "NO":  					$messaggio = "NEIN"; break;
 case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Verzeichnisse, in denen Webseiten erzeugt werden"; break;
-case "percorsi separati da virgole relativi":	$messaggio = "Pfade getrennt mit Komma, relativ zum Hoteldruid-Verzeichnis"; break;
 case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "wenn sie nicht mit / beginnen"; break;
 case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "Ich habe keine Schreibberechtigung im Verzeichnis"; break;
 case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "Das eingegebene Verzeichnis <div style=\"display: inline; color: red;\">existiert nicht</div>"; break;
@@ -300,7 +279,6 @@ case "2° codice":  				$messaggio = "2. Code"; break;
 case "3° codice":  				$messaggio = "3. Code"; break;
 case "Tabella con i documenti salvati":  	$messaggio = "Tabelle mit gespeicherten Dokumenten"; break;
 case "Il numero delle righe della tabella con i documenti salvati è stato cambiato":	$messaggio = "Die Tabelle mit den gespeicherten Dokumenten wurde ge&auml;ndert"; break;
-case "valore a cui arrotondare le percentuali delle tasse":	$messaggio = "Steuern auf diesen Wert runden"; break;
 case "documenti salvati":  			$messaggio = "Gespeicherte Dokumente"; break;
 case "Scegli le righe aggiuntive da mostrare":	$messaggio = "Weitere Spalten zur Anzeige ausw&auml;hlen"; break;
 case "tasse":  					$messaggio = "Steuern"; break;
@@ -331,11 +309,15 @@ case "città":  					$messaggio = "Stadt"; break;
 case "indirizzo":  				$messaggio = "Adresse"; break;
 case "codice postale":  			$messaggio = "Postleitzahl"; break;
 case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "Die Felder die bei der Suche ber&uuml;cksichtigt werden, wurden ge&auml;ndert"; break;
+case "Personalizza":  				$messaggio = "Customize"; break;
+case "Nome della valuta principale":  		$messaggio = "Name of the main currency"; break;
+case "Regione/provincia":  			$messaggio = "Region"; break;
 case "L'allineamento dei giorni con la disponibilità nella tabella dei mesi è stato cambiato":	$messaggio = "Days alignment with availability in months table has been changed"; break;
 case "Allineare la disponibilità con le date di arrivo potrebbe generare confusione ed errori sulle date di partenza, si è sicuri di voler continuare?":	$messaggio = "Aligning availability with arrival dates may generate confusion and mistakes on departure dates, are you sure you want to continue?"; break;
 case "nella regione/provincia di":  		$messaggio = "in region of"; break;
 case "nella nazione":  				$messaggio = "in nation"; break;
 case "Nome":  					$messaggio = "Name"; break;
+case "valore a cui arrotondare le percentuali delle tasse e delle valute":	$messaggio = "rounding value for percentages of taxes and currencies"; break;
 case "commissioni":  				$messaggio = "commissions"; break;
 case "resto commissioni":  			$messaggio = "commissions rest"; break;
 case "Le righe aggiuntive sono state cambiate":	$messaggio = "Extra rows have been changed"; break;
@@ -381,15 +363,118 @@ case "L'accettazione di questa clausola conferma che gli sviluppatori di questo
 case "Accetto":  				$messaggio = "I Accept"; break;
 case "Declino":  				$messaggio = "I Decline"; break;
 case "La gestione dei codici cvc è stata cambiata":	$messaggio = "The management of CVC codes has been changed"; break;
-case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
 case "Scegli le righe con i totali da mostrare":	$messaggio = "Choose which totals to show in rows"; break;
 case "giornaliero":  				$messaggio = "daily"; break;
 case "mensile":  				$messaggio = "montly"; break;
 case "tabella":  				$messaggio = "table"; break;
+case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
 case "partenze e prenotazioni correnti":  	$messaggio = "departures and current reservations"; break;
+case "Commenti personalizzati delle prenotazioni":	$messaggio = "Custom comments for reservations"; break;
+case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Custom comment for reservation deleted"; break;
+case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "New custom comment for reservation added"; break;
+case "Punto vendita ed inventario":  		$messaggio = "Point of sale and inventory"; break;
+case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Sorting in inventory and point of sale"; break;
+case "alfabetico":  				$messaggio = "alphabetically"; break;
+case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
+case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
+case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
+case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
+case "Attenzione":  				$messaggio = "Warning"; break;
+case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "the links to export calendars in ical format have changed, remember to update them on external calendars"; break;
+case "La tariffa":  				$messaggio = "Rate"; break;
+case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
+case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "at least 8 characters, with letters and numbers or symbols"; break;
+case "diversa dalle ultime":  			$messaggio = "different from last"; break;
+case "Condizioni Generali di Contratto":  	$messaggio = "General Terms and Conditions"; break;
+case "del servizio di memorizzazione delle carte di credito":	$messaggio = "of the credit cards storage service"; break;
+case "La password non è stata modificata":  	$messaggio = "The password has not been modified"; break;
+case "password errata":  			$messaggio = "wrong password"; break;
+case "adulto":  				$messaggio = "adult"; break;
+case "adulti":  				$messaggio = "adults"; break;
+case "bambino":  				$messaggio = "child"; break;
+case "bambini":  				$messaggio = "children"; break;
+case "Numero di tipologie di persone":  	$messaggio = "Number of people types"; break;
+case "Tipologia":  				$messaggio = "Type"; break;
+case "Può essere ospite principale":  		$messaggio = "Can be main guest"; break;
+case "Prezzo in percentuale del prezzo per persona":	$messaggio = "Price in percentage of per person price"; break;
+case "arrotondato a":  				$messaggio = "rounded to"; break;
+case "Modifica le tipologie di persone":  	$messaggio = "Modify people types"; break;
+case "Il numero di tipologie di persone è sbagliato":	$messaggio = "The number of people types is wrong"; break;
+case "Il numero di tipologie di persone è stato cambiato":	$messaggio = "The number of people types has been changed"; break;
+case "I dati inseriti non sono corretti":  	$messaggio = "Inserted data are incorrect"; break;
+case "Le tipologie di persone sono state modificate":	$messaggio = "The people types have been modified"; break;
+case "Cambia per tutti gli utenti":  		$messaggio = "Change for all users"; break;
+case "Modifica le tipologie di persone per tutti gli utenti":	$messaggio = "Modify people types for all users"; break;
+case "tipi di persona":  			$messaggio = "person types"; break;
+case "Valuta secondaria chiamata":  		$messaggio = "Secundary currency called"; break;
+case "nuova valuta":  				$messaggio = "new currency"; break;
+case "con arrotondamento":  			$messaggio = "with rounding"; break;
+case "Aggiungi per tutti gli utenti":  		$messaggio = "Add for all users"; break;
+case "Elimina la valuta":  			$messaggio = "Delete the currency"; break;
+case "Elimina":  				$messaggio = "Delete"; break;
+case "Elimina per tutti gli utenti":  		$messaggio = "Delete for all users"; break;
+case "La nuova valuta secondaria è stata aggiunta":	$messaggio = "The new secundary currency has been addded"; break;
+case "La valuta secondaria":  			$messaggio = "The secundary currency"; break;
+case "è stata modificata":  			$messaggio = "has been modified"; break;
+case "è stata eliminata":  			$messaggio = "has been deleted"; break;
+case "La cartella":  				$messaggio = "The directory"; break;
+case "è un duplicato":  			$messaggio = "is a duplicate"; break;
+case "le seguenti pagine web verranno cancellate":	$messaggio = "the following web pages will be deleted"; break;
+case "le tipologie di persone rimosse erano presenti in alcuni costi aggiuntivi, questi costi vanno aggiornati manualmente se necessario":	$messaggio = "removed person types were present in some extra costs, eventually these costs must be updated manually"; break;
+case "Utilizzo dei cookies per la gestione delle sessioni attivato":	$messaggio = "Use of cookies for session handling enabled"; break;
+case "Utilizzo dei cookies per la gestione delle sessioni disattivato":	$messaggio = "Use of cookies for session handling disabled"; break;
+case "Percorso al file autoload.php di phpmailer":	$messaggio = "Path to autoload.php file for phpmailer"; break;
+case "per inviare email attraverso un server remoto":	$messaggio = "to send emails through a remote server"; break;
+case "Per inviare le email usare":  		$messaggio = "To send emails use"; break;
+case "il server locale":  			$messaggio = "the local server"; break;
+case "un server remoto":  			$messaggio = "a remote server"; break;
+case "Server di posta SMTP":  			$messaggio = "SMTP mail server"; break;
+case "Sicurezza connessione":  			$messaggio = "Connection security"; break;
+case "nessuna":  				$messaggio = "no one"; break;
+case "Il percorso al file autoload.php di phpmailer è stato cambiato":	$messaggio = "The path to autoload.php file for phpmailer has been changed"; break;
+case "Il file inserito <span class=\"colred\">non carica phpmailer</span> correttamente":	$messaggio = "The inserted file <span class=\"colred\">does not load phpmailer</span> correctly"; break;
+case "Il metodo per inviare le email è stato cambiato":	$messaggio = "The method to send emails has been changed"; break;
+case "Connessione fallita":  			$messaggio = "Falied connection"; break;
+case "EHLO fallito":  				$messaggio = "Failed EHLO"; break;
+case "Connessione cifrata STARTTLS fallita":  	$messaggio = "STARTTLS encrypted connection failed"; break;
+case "EHLO dopo STARTTLS fallito":  		$messaggio = "EHLO after STARTTLS failed"; break;
+case "Autenticazione fallita":  		$messaggio = "Failed authentication"; break;
+case "I dati per il collegamento al server SMTP sono <span class=\"colred\">sbagliati o incompleti</span>":	$messaggio = "The data to connect to the SMTP server are <span class=\"colred\">wrong or incomplete</span>"; break;
+case "I dati per il collegamento al server SMTP sono stati aggiornati":	$messaggio = "The data to connect to the SMTP server have been updated"; break;
+case "controllando SPF":  			$messaggio = "checking SPF"; break;
+case "Attualmente SPF è configurato correttamente sul dominio della email della struttura":	$messaggio = "Currently SPF is correctly configured on the domain of the property email"; break;
+case "Attualmente <span class=\"colred\">SPF non è configurato correttamente</span> sul dominio della email della struttura":	$messaggio = "Currently <span class=\"colred\">SPF is not configured correctly</span> on the domain of the property email"; break;
+case "Il mascheramento delle email verrà attivato solo se nel DNS del dominio dell'email del mittente c'è un record TXT per SPF contenente":	$messaggio = "Email masquerading will be activated only if in the DNS of the domain of the sender's email there is a TXT record for SPF containing"; break;
+case "Il dominio":  				$messaggio = "The domain"; break;
+case "non ha nessun record per SPF":  		$messaggio = "has no record for SPF"; break;
+case "nella gestione del suo DNS va aggiunto un record TXT contenente un testo come questo":	$messaggio = "in the management of your DNS you must add a TXT record containing a text like this"; break;
+case "Questo è il record SPF attuale del dominio":	$messaggio = "This is the current SPF record of the domain"; break;
+case "questo record TXT va modificato nella gestione del DNS del dominio":	$messaggio = "this TXT record must be modified in the management of DNS of the domain"; break;
+case "sostituendolo con un testo come questo":	$messaggio = "replacing it with a text like this"; break;
+case "Dopo la modifica potrebbero volerci alcune ore affinchè l'aggiornamento sia attivo":	$messaggio = "After the change it may take a few hours for the update to take effect"; break;
+case "Formato di nomi e cognomi":  		$messaggio = "Format of names and surnames"; break;
+case "non modificare il formato inserito":  	$messaggio = "don't modify inserted format"; break;
+case "prima lettera maiuscola, altre lettere minuscole":	$messaggio = "first letter uppercase, other letters lowercase"; break;
+case "prima lettera maiuscola, non modificare altre lettere":	$messaggio = "first letter uppercase, do not change other letters"; break;
+case "tutte lettere maiuscole":  		$messaggio = "all letters uppercase"; break;
+case "tutte lettere minuscole":  		$messaggio = "all letters lowercase"; break;
+case "Il formato di inserimento dei nomi e cognimi è stato cambiato":	$messaggio = "The format for inserting names and surnames has been changed"; break;
+case "Per il proprio indirizzo email si sta usando un provider pubblico":	$messaggio = "For your email address you are using a public provider"; break;
+case "si consiglia quindi di":  		$messaggio = "it is therefore advisable to"; break;
+case "configurare il loro server remoto smtp":	$messaggio = "configure their remote smtp server"; break;
+case "per inviare email":  			$messaggio = "to avoid that emails sent"; break;
+case "da hoteldruid":  				$messaggio = "from hoteldruid"; break;
+case "senza che vengano considerate come spam":	$messaggio = "are considered as spam"; break;
+case "percorsi relativi":  			$messaggio = "paths relative"; break;
+case "Secondo cognome disattivato":  		$messaggio = "Second surname disabled"; break;
+case "Secondo cognome attivato":  		$messaggio = "Second surname enabled"; break;
+case "Fuso orario":  				$messaggio = "Time zone"; break;
+case "nessun fuso orario":  			$messaggio = "no time zone"; break;
+case "Si possono creare solo cartelle con nome composto da lettere e numeri":	$messaggio = "Only folders with names that contain letters and numbers can be created"; break;
+case "la seguente cartella verrà creata":  	$messaggio = "the following folder will be created"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
