@@ -3,7 +3,6 @@
 switch ($messaggio) {
 
 case "Inserisci una nuova prenotazione":                 $messaggio = "Buchung erfassen"; break;
-case "Cliente titolare: cognome":                        $messaggio = "Nachname "; break;
 case "cognome":                                          $messaggio = "Nachname"; break;
 case "nome":                                             $messaggio = "Vorname"; break;
 case "Dal":                                              $messaggio = "Vom"; break;
@@ -85,7 +84,6 @@ case "Modifica come gruppo le prenotazioni inserite":    $messaggio = "&Auml;nde
 case "prezzo totale":                                    $messaggio = "Gesamtpreis"; break;
 case "prezzo totale giornaliero":                        $messaggio = "Summe Tagespreis"; break;
 case "prezzo totale settimanale":                        $messaggio = "Summe Wochenpreis"; break;
-case "prezzo tarffa":                                    $messaggio = "Tagessatz"; break;
 case "prezzo tariffa giornaliero":                       $messaggio = "Tagessatz Preis"; break;
 case "prezzo tariffa settimanale":                       $messaggio = "Wochensatz Preis"; break;
 case "% del totale":                                     $messaggio = "% auf Summe"; break;
@@ -93,12 +91,23 @@ case "% della tariffa":                                  $messaggio = "% &uuml;b
 case "Commissioni":                                      $messaggio = "Nachl&auml;sse"; break;
 case "resto commissioni":                                $messaggio = "offene Provisionen"; break;
 case "% del prezzo totale":  			         $messaggio = "% vom Gesamtpreis"; break;
+case "Prenota":  				$messaggio = "Reserve"; break;
+case "Cliente titolare":  			$messaggio = "Titular client"; break;
+case "OVERBOOKING":  				$messaggio = "OVERBOOKING"; break;
+case "prezzo tariffa":  			$messaggio = "rate price"; break;
 case "modificata":  				$messaggio = "modified"; break;
 case "Errore":  				$messaggio = "Error"; break;
 case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
 case "per la prenotazione":  			$messaggio = "for reservation"; break;
-case "per l'entrata":  				$messaggio = "for checkin"; break;
-case "per l'uscita":  				$messaggio = "for checkout"; break;
+case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
+case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
+case "valuta":  				$messaggio = "currency"; break;
+case "Il numero di persone inserite non include i bambini (vedere il commento per il numero di bambini)":	$messaggio = "The inserted number of people does not include children (see comment for the number of children)"; break;
+case "da":  					$messaggio = "from"; break;
+case "Si è dovuto diminuire il <b>numero di persone</b> per inserire la prenotazione":	$messaggio = "The <b>number of people</b> has been decreased in order to insert the reservation"; break;
+case "Prenotazione non inserita":  		$messaggio = "Reservation not inserted"; break;
+case "Prenotazione non modificata":  		$messaggio = "Reservation not modified"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
