@@ -5,6 +5,7 @@
 # numbers and underscore: NO ACCENTS, NO SPACES
 
 $trad_var['cognome'] = 'vorname';
+$trad_var['cognome2'] = 'surname2';
 $trad_var['nome'] = 'name';
 $trad_var['soprannome'] = 'nickname';
 $trad_var['titolo'] = 'titel';
@@ -32,11 +33,15 @@ $trad_var['telefono2'] = 'telefon2';
 $trad_var['telefono3'] = 'telefon3';
 $trad_var['fax'] = 'telefax';
 $trad_var['email'] = 'email';
+$trad_var['email2'] = 'email2';
+$trad_var['email_certificata'] = 'certified_email';
 $trad_var['codice_fiscale'] = 'steuernummer';
 $trad_var['partita_iva'] = 'umsatzsteuernummer';
+$trad_var['numero_cliente'] = 'client_number';
 $trad_var['num_persone'] = 'anzahl_personen';
 $trad_var['n_letti_agg'] = 'extra_bett_anz';
 $trad_var['num_persone_tot'] = 'gaeste_anz_sum';
+$trad_var['num_persone_tipo'] = 'people_num_type';
 $trad_var['costo_tot'] = 'preis_sum';
 $trad_var['caparra'] = 'anzahlung';
 $trad_var['resto_caparra'] = 'anzahlung_offen';
@@ -44,16 +49,30 @@ $trad_var['data_inizio'] = 'start_datum';
 $trad_var['data_fine'] = 'end_datum';
 $trad_var['num_periodi'] = 'perioden_anz';
 $trad_var['orario_entrata_stimato'] = 'geplante_checkin_zeit';
+$trad_var['orario_registrazione_entrata'] = 'checkin_time';
+$trad_var['orario_registrazione_uscita'] = 'checkout_time';
 $trad_var['nome_tariffa'] = 'tarif_name';
 $trad_var['costo_tariffa'] = 'tarif_preis';
 $trad_var['costo_tariffa_p'] = 'rate_price_p';
 $trad_var['costo_tariffa_giorno_array'] = 'rate_price_of_array_day';
 $trad_var['costo_tariffa_giorno_array_p'] = 'rate_price_of_array_day_p';
 $trad_var['sconto'] = 'skonto';
+$trad_var['valuta_tariffa'] = 'rate_currency';
+$trad_var['tasso_cambio_tariffa'] = 'rate_exchange_rate';
+$trad_var['costo_valuta_tariffa'] = 'rate_currency_price';
+$trad_var['costo_valuta_tot'] = 'price_currency_tot';
+$trad_var['valore_valuta_sconto'] = 'discount_currency_value';
+$trad_var['valuta_caparra'] = 'deposit_currency';
+$trad_var['valore_valuta_caparra'] = 'deposit_currency_value';
+$trad_var['tasso_cambio_caparra'] = 'deposit_exchange_rate';
+$trad_var['metodo_pagamento_caparra'] = 'deposit_payment_method';
 $trad_var['commento'] = 'bemerkung';
+$trad_var['promemoria_entrata'] = 'checkin_reminder';
+$trad_var['promemoria_uscita'] = 'checkout_reminder';
 $trad_var['origine_prenotazione'] = 'reservierung_quelle';
 $trad_var['unita_occupata'] = 'occupied_unit';
 $trad_var['unita_assegnabili'] = 'units_list';
+$trad_var['conferma'] = 'confirmation';
 $trad_var['pagato'] = 'bezahlt';
 $trad_var['pagato_p'] = 'bezahlt_p';
 $trad_var['resto_da_pagare'] = 'offene_zahlung';
@@ -74,6 +93,7 @@ $trad_var['sconto_senza_tasse_p'] = 'discount_without_taxes_p';
 $trad_var['nome_costo_agg'] = 'extra_cost_name';
 $trad_var['valore_costo_agg'] = 'extra_cost_value';
 $trad_var['valore_costo_agg_p'] = 'extra_cost_value_p';
+$trad_var['giorni_costo_agg'] = 'extra_cost_days';
 $trad_var['valore_tutti_costi_agg'] = 'value_all_extra_costs';
 $trad_var['valore_tutti_costi_agg_p'] = 'value_all_extra_costs_p';
 $trad_var['tutti_i_costi_agg'] = 'all_extra_costs';
@@ -92,6 +112,11 @@ $trad_var['valore_costo_agg_senza_tasse'] = 'extra_cost_value_without_taxes';
 $trad_var['valore_costo_agg_senza_tasse_p'] = 'extra_cost_value_without_taxes_p';
 $trad_var['moltiplica_max_costo_agg'] = 'extra_cost_max_multiply';
 $trad_var['moltiplica_max_costo_agg_sel'] = 'sel_extra_cost_max_multiply';
+$trad_var['valore_giornaliero_max_costo_agg'] = 'extra_cost_max_daily_value';
+$trad_var['valore_giornaliero_max_costo_agg_p'] = 'extra_cost_max_daily_value_p';
+$trad_var['valore_giornaliero_max_costo_agg_sel'] = 'sel_extra_cost_max_daily_value';
+$trad_var['valore_giornaliero_max_costo_agg_sel_p'] = 'sel_extra_cost_max_daily_value_p';
+$trad_var['tipo_persona_costo_agg'] = 'extra_cost_person_type';
 $trad_var['data_inserimento_costo_agg'] = 'extra_cost_insertion_date';
 $trad_var['utente_inserimento_costo_agg'] = 'extra_cost_insertion_user';
 $trad_var['percentuale_tasse_costo_agg_sel'] = 'sel_extra_cost_taxes_percentage';
@@ -101,11 +126,18 @@ $trad_var['sconto_p'] = 'discount_p';
 $trad_var['num_costi_aggiuntivi'] = 'extra_costs_number';
 $trad_var['valore_pagamento'] = 'payment_value';
 $trad_var['valore_pagamento_p'] = 'payment_value_p';
+$trad_var['valuta_pagamento'] = 'payment_currency';
+$trad_var['valore_valuta_pagamento'] = 'payment_currency_value';
+$trad_var['tasso_cambio_pagamento'] = 'payment_exchange_rate';
 $trad_var['data_pagamento'] = 'payment_date';
 $trad_var['utente_pagamento'] = 'payment_user';
 $trad_var['metodo_pagamento'] = 'payment_method';
+$trad_var['id_pagamento'] = 'payment_id';
+$trad_var['note_pagamento'] = 'payment_notes';
+$trad_var['data_operazione_pagamento'] = 'payment_transaction_date';
 $trad_var['tutti_i_pagamenti'] = 'all_payments';
 $trad_var['tutti_i_pagamenti_p'] = 'all_payments_p';
+$trad_var['ultimo_pagamento'] = 'last_payment';
 $trad_var['valore_ultimo_pagamento'] = 'last_payment_value';
 $trad_var['valore_ultimo_pagamento_p'] = 'last_payment_value_p';
 $trad_var['data_ultimo_pagamento'] = 'last_payment_date';
@@ -115,6 +147,7 @@ $trad_var['num_pagamenti'] = 'payments_number';
 $trad_var['numero_prenotazione'] = 'reservation_number';
 $trad_var['numero_ripetizione_prenotazioni'] = 'reservations_repetition_number';
 $trad_var['codice_prenotazione'] = 'reservation_code';
+$trad_var['ultima_prenotazione_per_cliente'] = 'last_reservation_for_client';
 $trad_var['data_inserimento_prenotazione'] = 'reservation_insertion_date';
 $trad_var['utente_inserimento_prenotazione'] = 'reservation_insertion_user';
 $trad_var['numero_progressivo_documento'] = 'document_progressive_number';
@@ -155,7 +188,9 @@ $trad_var['codice3_regione_documento'] = 'document_region_code3';
 $trad_var['codice3_nazione_documento'] = 'document_nation_code3';
 $trad_var['num_ospiti_tot'] = 'guests_tot_num';
 $trad_var['numero_ospite'] = 'number_guest';
+$trad_var['numero_cliente_ospite'] = 'client_number_guest';
 $trad_var['cognome_ospite'] = 'surname_guest';
+$trad_var['cognome2_ospite'] = 'surname2_guest';
 $trad_var['nome_ospite'] = 'name_guest';
 $trad_var['soprannome_ospite'] = 'nickname_guest';
 $trad_var['titolo_ospite'] = 'title_guest';
@@ -184,6 +219,8 @@ $trad_var['telefono2_ospite'] = 'telephone2_guest';
 $trad_var['telefono3_ospite'] = 'telephone3_guest';
 $trad_var['fax_ospite'] = 'fax_guest';
 $trad_var['email_ospite'] = 'email_guest';
+$trad_var['email2_ospite'] = 'email2_guest';
+$trad_var['email_certificata_ospite'] = 'certified_email_guest';
 $trad_var['codice_fiscale_ospite'] = 'fiscal_code_guest';
 $trad_var['partita_iva_ospite'] = 'vat_number_guest';
 $trad_var['codice_cittadinanza_ospite'] = 'nationality_code_guest';
@@ -228,6 +265,9 @@ $trad_var['piano_unita'] = 'unit_floor';
 $trad_var['capacita_unita'] = 'unit_capacity';
 $trad_var['priorita_unita'] = 'unit_priority';
 $trad_var['num_unita'] = 'units_num';
+$trad_var['lista_inventario_unita'] = 'units_inventory_list';
+$trad_var['mancanti_inventario_unita'] = 'units_inventory_missing';
+$trad_var['dettagli_inventario_unita'] = 'units_inventory_details';
 $trad_var['costo_tot_somma_ripetizioni'] = 'price_tot_repetitions_sum';
 $trad_var['costo_tot_somma_ripetizioni_p'] = 'price_tot_repetitions_sum_p';
 $trad_var['caparra_somma_ripetizioni'] = 'deposit_repetitions_sum';
@@ -241,6 +281,7 @@ $trad_var['resto_da_pagare_somma_ripetizioni_p'] = 'rest_to_pay_repetitions_sum_
 $trad_var['num_persone_tot_somma_ripetizioni'] = 'people_num_tot_repetitions_sum';
 $trad_var['data_inizio_selezione'] = 'selection_starting_date';
 $trad_var['data_fine_selezione'] = 'selection_ending_date';
+$trad_var['numero_prenotazioni_selezione'] = 'selection_reservations_number';
 $trad_var['utente_attuale'] = 'current_user';
 $trad_var['nome_struttura'] = 'structure_name';
 $trad_var['tipo_struttura'] = 'structure_type';
@@ -249,6 +290,7 @@ $trad_var['ragione_sociale_struttura'] = 'structure_company_name';
 $trad_var['sito_web_struttura'] = 'structure_website';
 $trad_var['nome_contatto_struttura'] = 'structure_contact_name';
 $trad_var['nazione_struttura'] = 'structure_nation';
+$trad_var['regione_struttura'] = 'structure_region';
 $trad_var['comune_struttura'] = 'structure_city';
 $trad_var['indirizzo_struttura'] = 'structure_address';
 $trad_var['CAP_struttura'] = 'structure_postal_code';
@@ -258,16 +300,35 @@ $trad_var['codice_fiscale_struttura'] = 'structure_fiscal_code';
 $trad_var['partita_iva_struttura'] = 'structure_vat_number';
 $trad_var['numero_stelle_struttura'] = 'structure_stars_number';
 $trad_var['logo_struttura'] = 'structure_logo';
+$trad_var['codice_nazione_struttura'] = 'structure_nation_code';
+$trad_var['codice_regione_struttura'] = 'structure_region_code';
+$trad_var['codice_comune_struttura'] = 'structure_city_code';
+$trad_var['codice2_nazione_struttura'] = 'structure_nation_code2';
+$trad_var['codice2_regione_struttura'] = 'structure_region_code2';
+$trad_var['codice2_comune_struttura'] = 'structure_city_code2';
+$trad_var['codice3_nazione_struttura'] = 'structure_nation_code3';
+$trad_var['codice3_regione_struttura'] = 'structure_region_code3';
+$trad_var['codice3_comune_struttura'] = 'structure_city_code3';
+$trad_var['nome_valuta'] = 'currency_name';
 $trad_var['testo_email_richiesta'] = 'enquiry_email_text';
 $trad_var['testo_quotato_email_richiesta'] = 'enquiry_email_quoted_text';
-$trad_var['nome_valuta'] = 'currency_name';
+$trad_var['url_base_pagine_web'] = 'base_url_for_webpages';
 $trad_var['ritorno_a_capo'] = 'carriage_return';
 $trad_var['avanzamento_riga'] = 'new_line';
+$trad_var['valore_nullo'] = 'null_value';
 $trad_var['errore_ripetizione'] = 'repetition_error';
 $trad_var['messaggio_di_errore'] = 'error_message';
 $trad_var['codice_lingua'] = 'language_code';
 $trad_var['email_gia_inviata'] = 'email_already_sent';
+$trad_var['commento_personalizzato'] = 'custom_comment';
 $trad_var['campo_personalizzato'] = 'custom_field';
+$trad_var['nome_documento_salvato'] = 'saved_document_name';
+$trad_var['numero_progressivo_documento_salvato'] = 'saved_document_progressive_number';
+$trad_var['data_creazione_documento_salvato'] = 'saved_document_creation_date';
+$trad_var['nome_file_documento_salvato'] = 'saved_document_filename';
+$trad_var['nome_download_documento_salvato'] = 'saved_document_download_name';
+$trad_var['nome_documento_scaricato'] = 'downloaded_document_name';
+$trad_var['allegato'] = 'attachment';
 
 
 ?>
\ No newline at end of file
